@@ -384,7 +384,7 @@ impl Cli {
                 skip_helm,
                 provider,
             } => {
-                let name = name.or_else(k8s::get_cluster_name).ok_or_else(|| {
+                let name = name.or_else(k8s::get_current_cluster_name).ok_or_else(|| {
                     anyhow::anyhow!(
                         "No default Kubernetes context found, need to provide cluster name"
                     )
@@ -413,7 +413,7 @@ impl Cli {
             }
             Command::ListClusters => statehub.list_clusters().await,
             Command::ShowCluster { name } => {
-                let name = name.or_else(k8s::get_cluster_name).ok_or_else(|| {
+                let name = name.or_else(k8s::get_current_cluster_name).ok_or_else(|| {
                     anyhow::anyhow!(
                         "No default Kubernetes context found, need to provide cluster name"
                     )
@@ -483,6 +483,7 @@ pub(crate) struct StateHub {
     config: Config,
     api: api::Api,
     stdout: Term,
+    stderr: Term,
     theme: theme::SimpleTheme,
     json: bool,
     verbose: bool,
@@ -492,12 +493,14 @@ impl StateHub {
     fn new(config: Config, json: bool, verbose: bool) -> Self {
         let api = api::Api::new(config.api(), config.token());
         let stdout = Term::stdout();
+        let stderr = Term::stderr();
         let theme = theme::SimpleTheme;
 
         Self {
             config,
             api,
             stdout,
+            stderr,
             theme,
             json,
             verbose,
@@ -628,14 +631,12 @@ impl StateHub {
         self.setup_cluster_token_helper(&cluster, &helm).await?;
         self.setup_configmap_helper(&cluster, &helm).await?;
 
-        helm.execute(&cluster)
-            .await
-            .and_then(|text| self.inform(text))?;
-
         if claim_unowned_states {
             self.claim_unowned_states_helper(&cluster, states).await?;
         }
 
+        self.helm_install_helper(&helm, &cluster).await?;
+
         cluster.print(&self.stdout, self.json)
     }
 
@@ -912,6 +913,14 @@ impl StateHub {
         Ok(())
     }
 
+    fn error(&self, text: impl fmt::Display) -> io::Result<()> {
+        let text = text.to_string();
+        if !text.is_empty() {
+            self.stderr.write_line(&text)?;
+        }
+        Ok(())
+    }
+
     fn input(&self, prompt: impl Into<String>) -> io::Result<String> {
         Input::with_theme(self.theme())
             .with_prompt(prompt)
